from distutils.core import setup
setup(
  name = 'emailDNS',
  packages = ['emailDNS'], # this must be the same as the name above
  version = '1.1',
  description = 'An auto-robot for new IP reporting service into your Email address',
  author = 'Clock ZHONG',
  author_email = 'zhong.clock@gmail.com',
  url = 'https://github.com/clockzhong/EmailBridgeForIPReport',
  download_url = 'https://github.com/clockzhong/EmailBridgeForIPReport/archive/1.1.tar.gz',
  keywords = ['testing', 'logging', 'example'],
  classifiers = [],
)